# How to generate a PIP package?
- Change setup.cfg version
- py -m build
- py -m twine upload --skip-existing dist/*

Use this api key: pypi-AgEIcHlwaS5vcmcCJDJiOTdhYWUwLTE1MmQtNDJmMS1iYmU4LTgzZmM2MDNlZDQ5NQACFlsxLFsic2NyYXBlYW55dGhpbmciXV0AAixbMixbIjU3MTA5MDEwLTdmYTEtNGMzNi1hZGVhLTg1NGZiYmI0OWYwMyJdXQAABiC9cH3BsU3LX0DPjZpayxHzYHCnCa5WAt-1KX1hSMj9Eg

Reference: https://packaging.python.org/en/latest/tutorials/packaging-projects/